@@ -15,9 +15,13 @@ class AlreadyInstalled(StringAttr.StringAttr):
 		r = Reason()
 		home = UniversalCache.UniversalCache('home')
 		r,p = home.get(Package.Spec(self.value))
-		if r.ok(): r = p.satisfied()
-		if not r.ok(): 
-			r = Reason('Package ['+self.value+'] must be installed first.')
+		if r.ok(): 
+			if p.lastfail: 
+				r = Reason('Package ['+p.str()+'] is present but failed to install.')
+			elif not p.lastsat:
+				r = Reason('Package ['+p.str()+'] is fetched but has not been installed.')
+		else:
+			r = Reason('Package ['+self.value+'] is not already installed.')
 		return r
 
 	def satisfiable(self): return self.satisfied()
