@@ -35,6 +35,7 @@ from AtomsExec              import *
 import Package
 import dictParser
 import string
+import RelPath
 from types import *
 
 def get_src(source,file,cachename):
@@ -88,28 +89,19 @@ class AtomParser:
 		return e
 	def fixup(self,e):
 		if e.type=='lazy package':
-##			if len(e._spec.caches)==0: e._spec.caches = [self.cachename]
-#			spec           = Package.Spec()
-#			spec.name      = self.packagename
-#			e._parent      = spec
 			e._parent      = self._spec
 			e._parent.caches = []
 			e._parent.guard = ''
 		elif e.type=='restore':
 			e._par = Package.Spec(self.cachename+':'+self.packagename)
 		elif e.type=='download':
-			if os.path.dirname(e._url)=='':
-				e._url = os.path.join(self.cachename,e._url)
+			if RelPath.relPath(e._url): e._url = os.path.join(self.cachename,e._url)
 		elif e.type=='timed download':
-			if os.path.dirname(e._download._url)=='':
-				e._download._url = os.path.join(self.cachename,e._download._url)
+			if RelPath.relPath(e._url): e._download._url = os.path.join(self.cachename,e._download._url)
 		elif e.type=='downloadUntarzip':
-			if os.path.dirname(e._download._url)=='':
-				e._download._url = os.path.join(self.cachename,e._download._url)
-			
+			if RelPath.relPath(e._url): e._download._url = os.path.join(self.cachename,e._download._url)
 		e._parentPackageName = self.packagename
 		return e
-#		return newAttributeExec(text)
 
 	def parse(self,text):
 		if not newAttributeText(text) and string.strip(text)!='':
@@ -272,7 +264,6 @@ class AtomParser:
 			self.syntaxCheck(download,downloadOK,text)
 			downloads = dictParser.dictParser(text)
 			eno = OR(); eno._seq = 12
-#			for platform,downfile in download.items():
 			for platform,downfile in downloads:
 				enp = AND()
 				if downfile!='':
