@@ -10,6 +10,7 @@ newAttributes = ['setenv','exists','inpath','which','packageName', \
 		 'platform','platformLE','platformLT','platformGE','platformGT',\
 		 'url','urlVisible','updateUrl','cat',\
 		 'shell','shellDialogue','shellOutputContains','shellOutputLE','shellOutputEQ','shellOutputGE',\
+		 'shellOutputLT','shellOutputGT',\
 		 'uninstallShell','pythonScript',\
 		 'workspace','fail','alreadyInstalled',\
 		 'setenvTemp','unsetenv','envIsSet','envHasValue',\
@@ -23,9 +24,9 @@ newAttributes = ['setenv','exists','inpath','which','packageName', \
 		 'openFileDescriptorsSoft','openFileDescriptorsHard','openFileDescriptors',\
 		 'remoteInstallation','description',\
 		 'freeMegsMinimum','freeMegs','copy','cp','copyReplace','ls','cu',\
-		 'cd','download','downloadUntar','downloadUntarzip','cwd','locate',\
+		 'cd','download','downloadUntar','downloadUntarzip','downloadUntarZip','cwd','locate',\
 		 'export','package','packageDirectory','watch',\
-		 'yes','no','choice','insertLine',\
+		 'yes','no','choice','insertLine','freeDisk',\
 		 'md5check',\
 		 'message','echo','mail',\
 		 'remoteSite','remotePackage','remoteGroup',\
@@ -47,12 +48,14 @@ newAttributes = ['setenv','exists','inpath','which','packageName', \
 		 'byteOrder','systemWordSize','processor','systemVersion',\
 		 'tag','tagLE','tagGE','tagLT','tagGT',\
 		 'gccVersion','gccVersionLE','gccVersionLT','gccVersionGE','gccVersionGT',\
+		 'glibcVersion','glibcVersionLE','glibcVersionLT','glibcVersionGE','glibcVersionGT',\
 		 'pythonVersion','pythonVersionLE','pythonVersionLT','pythonVersionGE','pythonVersionGT',\
 		 'sshVersion','sshVersionLE','sshVersionLT','sshVersionGE','sshVersionGT',\
 		 'perlVersion','perlVersionLE','perlVersionLT','perlVersionGE','perlVersionGT',\
 		 'pacmanVersion','pacmanVersionLE','pacmanVersionLT','pacmanVersionGE','pacmanVersionGT',\
 		 'linuxKernel','linuxKernelLE','linuxKernelLT','linuxKernelGE','linuxKernelGT',\
 		 'true','false','packageName','setup',\
+		 'setenvShell','setenvShellTemp',\
 		 'env','installerChosenWorkSpace','directUntarzip',\
 		 'worldRead','worldWrite','worldExecute',\
 		 'groupRead','groupWrite','groupExecute',\
@@ -63,7 +66,45 @@ newAttributes = ['setenv','exists','inpath','which','packageName', \
 		 'register','alreadyInstalled','launchWebBrowser',\
 		 'fileCopyMinimumMegsPerSecond','downloadTime',\
 		 'commandLineSwitch','emptyDirectory','directoryContains',\
-		 'configure',\
+		 'configure','commandLineSwitch',\
+		 'isWorldRead','isWorldWrite','isWorldExecute',\
+		 'isGroupRead','isGroupWrite','isGroupExecute',\
+		 'isOwnerRead','isOwnerWrite','isOwnerExecute',\
+		 'isWorldRead','isWorldWrite','isWorldExecute',\
+		 'isGroupRead','isGroupWrite','isGroupExecute',\
+		 'isOwnerReadable','isOwnerWriteable','isOwnerExecuteable',\
+		                   'isOwnerWritable','isOwnerExecutable',\
+		 'isWorldReadable','isWorldWriteable','isWorldExecuteable',\
+		                   'isWorldWritable','isWorldExecutable',\
+		 'isGroupReadable','isGroupWriteable','isGroupExecuteable',\
+		                   'isGroupWritable','isGroupExecutable',\
+		 'isOwnerReadable','isOwnerWriteable','isOwnerExecuteable',\
+		                   'isOwnerWritable','isOwnerExecutable',\
+		 'isWorldReadable','isWorldWriteable','isWorldExecuteable',\
+		                   'isWorldWritable','isWorldExecutable',\
+		 'isGroupReadable','isGroupWriteable','isGroupExecuteable',\
+		                   'isGroupWritable','isGroupExecutable',\
+		 'isOwnerReadable','isOwnerWriteable','isOwnerExecuteable',\
+		                   'isOwnerWritable','isOwnerExecutable',\
+		 'setWorldRead','setWorldWrite','setWorldExecute',\
+		 'setGroupRead','setGroupWrite','setGroupExecute',\
+		 'setOwnerRead','setOwnerWrite','setOwnerExecute',\
+		 'setWorldRead','setWorldWrite','setWorldExecute',\
+		 'setGroupRead','setGroupWrite','setGroupExecute',\
+		 'setOwnerRead','setOwnerWrite','setOwnerExecute',\
+		 'setWorldReadable','setWorldWriteable','setWorldExecuteable',\
+		                    'setWorldWritable','setWorldExecutable',\
+		 'setGroupReadable','setGroupWriteable','setGroupExecuteable',\
+		                    'setGroupWritable','setGroupExecutable',\
+		 'setOwnerReadable','setOwnerWriteable','setOwnerExecuteable',\
+		                    'setOwnerWritable','setOwnerExecutable',\
+		 'setWorldReadable','setWorldWriteable','setWorldExecuteable',\
+		                    'setWorldWritable','setWorldExecutable',\
+		 'setGroupReadable','setGroupWriteable','setGroupExecuteable',\
+		                    'setGroupWritable','setGroupExecutable',\
+		 'setOwnerReadable','setOwnerWriteable','setOwnerExecuteable',\
+		                    'setOwnerWritable','setOwnerExecutable',\
+		 'absPath','usePort',\
 		 'directUntar','chooseDirectory']
 
 def abcommand(c):
