@@ -4,7 +4,7 @@
 import os
 from Environment import *
 from StringAttr  import *
-import Cookie
+import Pookie
 
 class Unsetenv(Environment):
 	type   = 'unsetenv'
@@ -108,10 +108,10 @@ class EnvHasValue(EnvIsSet):
 			if switch('ignore-cookies'):
 				val = raw_input('Choose a value for ['+self.name+']: ')
 			elif self._query=='': 
-				c = Cookie.CookieQuestion('Choose a value for ['+self.name+']',lambda x: x)
+				c = Pookie.CookieQuestion('Choose a value for ['+self.name+']',lambda x: x)
 				val = c.answer()
 			else:
-				c = Cookie.CookieQuestion(self._query,lambda x: x)
+				c = Pookie.CookieQuestion(self._query,lambda x: x)
 				val = c.answer()
 		else:              
 			val = self.valu
