@@ -1,5 +1,5 @@
 #
-#	Copyright, Saul Youssef, August 2003
+#	Copyright, Saul Youssef, 2005
 #
 from Base  import *
 from CU    import *
@@ -30,6 +30,7 @@ def executeBase(command,mode=''):
 		if reason.ok():
 			if mode=='compatibility': com = sustr(alias(os.path.expandvars(command)))
 			else:                     com = sustr(alias(                   command) )
+			if verbo('shell-out'): print 'About to execute ['+com+'] as user ['+currentuser+'] at ['+os.getcwd()+'].'
 			if ask('shell-all','About to execute ['+com+'] as user ['+currentuser+'] at ['+os.getcwd()+']. OK?'):
 				if currentuser!='root' or ask('root-shell','About to execute ['+os.path.expandvars(command)+'] as user ['+currentuser+'] at ['+os.getcwd()+']. OK?'):
 					verbo.log('shell-all','About to execute ['+com+'] as user ['+currentuser+'] at ['+os.getcwd()+'].')
@@ -52,22 +53,28 @@ def executeBase(command,mode=''):
 							else:                          print 'PATH undefined'
 							print 'status=',status
 							print 'output=['+output+']'
-					verbo.log('shell-all','Finished executing ['+com+'] as user ['+currentuser+'] at ['+os.getcwd()+'].')
-					if status!=0: 
-						reason.reason(output)
+					verbo.log('shell-all','Finished executing ['+com+'] as user ['+currentuser+'] at ['+cwdd()+'].')
+					if status!=0: reason.reason(output)
 
 					if output!='':
+						if verbo('shell-out'): print output
+						if not os.path.exists(os.path.join(pac_anchor,pacmanDir,'logs','shellout.log')):
+							verbo.log('io','Creating shellout.log...')
+							try:
+								f.open(os.path.join(pac_anchor,pacmanDir,'logs','shellout.log'),'w')
+								f.write('- Shell output log\n')
+								f.close()
+							except:
+								pass
 						try:
-							if os.environ.has_key('PAC_ANCHOR') and os.path.isdir(fullpath('$PAC_ANCHOR/'+pacmanDir+'/logs')):
-								f =  open(fullpath('$PAC_ANCHOR/'+pacmanDir+'/logs/shellout.log'),'a')
-								f.write(output+'\n')
-								f.close()
-							else:
-								f =  open('shellout.log','a')
-								f.write(output+'\n')
-								f.close()
+							f = open(os.path.join(pac_anchor,pacmanDir,'logs','shellout.log'),'a')
+							if verbo('io'): print 'Writing to shellout.log...'
+							f.write('shell command> '+command+'\n')
+							f.write(output+'\n')
+							f.close()
 						except (IOError,OSError):
-							reason = Reason("Can't write shell output to log file.")
+							pass
+#							reason = Reason("Can't write shell output to log file.")
 				else:
 					reason = Reason('Installer has denied permission to execute ['+command+'] as root.')
 			else:
@@ -79,5 +86,6 @@ def executeBase(command,mode=''):
 				reason.append(Reason('Shell command ['+command+'] has removed the current directory.'))
 	except (IOError,OSError):
 		reason.reason('Shell command ['+command+'] returns with an error.')
+	if debug('ignoreShellError'): reason = Reason()
 	return reason,output	
 
