@@ -28,8 +28,7 @@ class InPath(Environment):
 			reason = fileInPath(self._filename)
 			if reason.ok(): inPathcache[self._filename] = ''
 		return reason
-	def satisfiable(self): 
-		return self.satisfied()
+	def satisfiable(self): return self.satisfied()
 	
 class Which(InPath):
 	type   = 'which'
