@@ -2,7 +2,6 @@
 #	Copyright, August 2003, Saul Youssef
 #
 from Access import *
-import shutil
 
 class LocalAccess(Access):
 	type = 'local directory'
@@ -22,18 +21,22 @@ class LocalAccess(Access):
 			filenames = os.listdir(os.path.join(self.location,path))
 		except (IOError,OSError):
 			filenames = []
-			reason = Reason("No access to ["+os.path.join(self.location,path)+"].")
+			if os.path.exists(os.path.join(self.location,path)):
+				reason = Reason("Can't read ["+os.path.join(self.location,path)+"].")
+			else:
+				reason = Reason("Local file ["+os.path.join(self.location,path)+"] doesn't exist.")
 		return reason,filenames
 		
 	def getFile(self,name,target=''):
 		if target=='': target2 = name
 		else:          target2 = target
 		
-		reason = Reason()
-		try:
-			if verbo('io'): print 'Copying ['+name+'] to ['+target2+']...'
-			shutil.copyfile(os.path.join(self.location,name),fullpath(target2))
-		except (IOError,OSError):
-			reason = Reason("Error copying file ["+os.path.join(self.location,name)+"] to ["+fullpath(target2)+"].")
-
-		return reason
+		return safeCopy(os.path.join(self.location,name),fullpath(target2))
+#		reason = Reason()
+#		try:
+#			if verbo('io'): print 'Copying ['+name+'] to ['+target2+']...'
+#			shutil.copyfile(os.path.join(self.location,name),fullpath(target2))
+#		except (IOError,OSError):
+#			reason = Reason("Error copying file ["+os.path.join(self.location,name)+"] to ["+fullpath(target2)+"].")
+#
+#		return reason
