@@ -5,6 +5,7 @@ import time,cPickle,string,os,copy
 
 def mirrorDownloadReplace(accessString,e):
 	r = Reason()
+	
 	if    e.type=='package':
 		E = copy.deepcopy(e)
 		E._environ = mirrorDownloadReplace(accessString,e._environ)
@@ -291,10 +292,12 @@ class MirrorBaseCache(Cache.Cache):
 							
 	def contents(self,used):
 		r,ps = self.init(),[]
+		skipreplace = (switch('l') or switch('lc')) and not displayMode('cmp')
 		if r.ok(): 
 			for idd,qs in self._packages.items(): 
 				for q in qs:
-					qD = mirrorDownloadReplace(`self._access`,q)
+					if skipreplace: qD = q
+					else:           qD = mirrorDownloadReplace(`self._access`,q)
 					ps.append(qD)
 			sort(ps,Cache.plle)
 		if r.ok(): ps   = self.prependTop(ps)
@@ -307,6 +310,7 @@ class MirrorBaseCache(Cache.Cache):
 
 	def getAll(self,spec,used):
 		r,ps = self.init(),[]
+		skipreplace = (switch('l') or switch('lc')) and not displayMode('cmp')
 		if r.ok(): self.check(spec,used)
 		if r.ok() and len(self._packages)==0: r = Reason("Cache ["+self.UCL+"] is empty.")
 		if r.ok():
@@ -318,7 +322,8 @@ class MirrorBaseCache(Cache.Cache):
 				for p in qs:
 					if spec.satisfiedBy(p):
 						p._inCache = self.UCL
-						pD = mirrorDownloadReplace(`self._access`,p)
+						if skipreplace: pD = p
+						else:           pD = mirrorDownloadReplace(`self._access`,p)
 						ps.append(pD)
 						break
 		if r.ok(): ps   = self.prependTop(ps)
