@@ -67,6 +67,12 @@ def specParse(text):
 		
 	subdirectory,name = os.path.split(prefix)
 	return caches,name,subdirectory,guardstring
+	
+def sshtest(text):
+	ssh = 0
+	l = string.split(text,':')
+	if len(l)>0 and '@' in l[0] and text.count(':')>1: ssh = 1
+	return ssh
 		
 def specSplit(text):
 	front = ''; back = text
@@ -85,6 +91,15 @@ def specSplit(text):
 		elif  back[:7] =='gsiftp:':
 			front = front + back[:7]
 			back  =         back[7:]
+		elif  sshtest(back):
+			i = back.find(':')
+			if i>0:
+				front = front + back[:i] + ':'
+				back  =         back[i+1:]
+			i = back.find(':')
+			if i>0:
+				front = front + back[:i]
+				back  =         back[i:]
 		elif  back[0]==':':
 			back = back[1:]
 			break
