@@ -160,6 +160,14 @@ mtrans = {  'linux-redhat-6.0':'RedHat-6.1',
 	    'linux-sl-ific-5.5' :'IFIC-SL-5.5',
 	    'linux-sl-ific-5.6' :'IFIC-SL-5.6',
 	    'linux-sl-ific-5.7' :'IFIC-SL-5.7',
+	    'linux-centos-4.0' :'CentOS-4.0',
+	    'linux-centos-4.1' :'CentOS-4.1',
+	    'linux-centos-4.2' :'CentOS-4.2',
+	    'linux-centos-4.3' :'CentOS-4.3',
+	    'linux-centos-4.4' :'CentOS-4.4',
+	    'linux-centos-4.5' :'CentOS-4.5',
+	    'linux-centos-4.6' :'CentOS-4.6',
+	    'linux-centos-4.7' :'CentOS-4.7',
 	    'linux-rocks-5.0'    :'Rocks-5.0',
 	    'linux-rocks-5.1'    :'Rocks-5.1',
 	    'linux-rocks-5.2'    :'Rocks-5.2',
@@ -209,6 +217,7 @@ machines.append(('Tao',       'Linux',))
 machines.append(('SL',        'Linux',))
 machines.append(('Rocks',     'Linux',))
 machines.append(('BU-Linux',  'Linux',))
+machines.append(('CentOS',    'Linux',))
 
 #
 #-- Scientific Linux Family
@@ -263,6 +272,20 @@ machines.append((   'SuSE-3',  'SuSE-2',  ))
 machines.append((   'SuSE-2',  'SuSE-1',  ))
 machines.append((   'SuSE-1',  'SuSE',    ))
 
+#
+#-- CentOS
+#
+machines.append(('CentOS-4.7','CentOS-4.6',))
+machines.append(('CentOS-4.6','CentOS-4.5',))
+machines.append(('CentOS-4.5','CentOS-4.4',))
+machines.append(('CentOS-4.4','CentOS-4.3',))
+machines.append(('CentOS-4.3','CentOS-4.2',))
+machines.append(('CentOS-4.2','CentOS-4.1',))
+machines.append(('CentOS-4.1','CentOS-4.0',))
+machines.append(('CentOS-4.0','CentOS-4'  ,))
+machines.append(('CentOS-4',  'RHEL-4'    ,))
+machines.append(('CentOS-4',  'CentOS'    ,))
+
 #
 #-- Sun
 #
@@ -654,7 +677,7 @@ machines.append(('Fermi-SL-3.1','SL-3.1',        ))
 machines.append(('Fermi-SL-3.0','SL-3.0',        ))
 machines.append(('Fermi-SL-3'  ,'SL-3',          ))
 		
-supportedPlatforms = ['BU-Linux','RedHat','Fedora','Cygwin','RHEL','AIX','SuSE', 'Debian','Tao','SL','OSF1','MacOS','Rocks','Sun','FreeBSD','Irix']
+supportedPlatforms = ['BU-Linux','RedHat','CentOS','Fedora','Cygwin','RHEL','AIX','SuSE', 'Debian','Tao','SL','OSF1','MacOS','Rocks','Sun','FreeBSD','Irix']
 supportedPlatforms.sort()
 
 Machines = FinitePreOrder.FinitePreOrder(machines)
