@@ -6,26 +6,28 @@ import pickle
 
 def registry0():
 	reg = {}
-	reg['am-BU']     = Register(    'am-BU',  'http://atlas.bu.edu/caches/Atlas.mirror/','ATLAS mirror at BU',  'BU',   'S. Youssef','http://physics.bu.edu/~youssef/')
-	reg['BU']        = Register(       'BU',  'http://atlas.bu.edu/caches/',                                                     'Atlas Tier 2, Boston University',  'http://physics.bu.edu/~usatlas/',         'Saul Youssef',       'http://physics.bu.edu/~youssef/')
+	reg['ATLAS']     = Register(    'ATLAS',  'http://atlas-computing.web.cern.ch/atlas-computing/links/monolith/whole/ATLAS.caches',                 'The Atlas Experiment, CERN',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/sit/Distribution/', 'SIT', 'atlas-sw-sit@cern.ch')
+	reg['Atlas']     = Register(    'Atlas',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/pacman/whole/ATLAS.caches',                 'The Atlas Experiment, CERN',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/sit/Distribution/', 'SIT', 'atlas-sw-sit@cern.ch')
+	reg['am-CERN']      = Register(  'am-CERN',  'http://atlas-computing.web.cern.ch/atlas-computing/links/mirror/Atlas.mirror/','ATLAS mirror at CERN','CERN','SIT','atlas-sw-sit@cern.ch')
+	reg['am-IU']      = Register(  'am-IU',  'http://pacman.uits.indiana.edu/atlas/Atlas.mirror/','ATLAS mirror at IU','Indiana University','Kristy Kallbac-Rose','kallbac@indiana.edu')
+	reg['am-CERN-afs']  = Register(  'am-CERN-afs',  '/afs/cern.ch/atlas/software/am-CERN/Atlas.mirror/','ATLAS mirror at CERN','CERN','SIT','atlas-sw-sit@cern.ch')
+	reg['am-BU']        = Register(    'am-BU',  'http://atlas.bu.edu/caches/Atlas.mirror/','ATLAS mirror at BU',  'BU',   'S. Youssef','http://physics.bu.edu/~youssef/')
+	reg['BU']           = Register(       'BU',  'http://atlas.bu.edu/caches/',                                                     'Atlas Tier 2, Boston University',  'http://physics.bu.edu/~usatlas/',         'Saul Youssef',       'http://physics.bu.edu/~youssef/')
 	reg['am-BNL']    = Register(   'am-BNL',  'http://www.usatlas.bnl.gov/computing/cache/Atlas.mirror/','ATLAS mirror at BNL',  'BNL',   'Alex Undrus','undrus@bnl.gov')
 	reg['HLT']       = Register(      'HLT',  'http://atlas.web.cern.ch/Atlas/project/hlt/admin/www/pacman/cache/','ATLAS HLT',  'CERN',   'Jiri Masik','Jiri.Masik@cern.ch')
 	reg['KV']        = Register(       'KV',  'http://classis01.roma1.infn.it/pacman/cache/','ATLAS Kit Validation',  'INFN, Italy',   'Alessandro De Salvo','Alessandro.De.Salvo@cern.ch')
 	reg['Dartmouth'] = Register('Dartmouth',  'http://grid.dartmouth.edu/pacman/',                                                                     'Dartmouth',  'Dartmouth College',                       'James E. Dobson',                       'James.E.Dobson@Dartmouth.EDU')
 	reg['OU']        = Register(       'OU',  'http://www-hep.nhn.ou.edu/pacman-cache/',                                                  'University of Oklahoma',  'http://www-hep.nhn.ou.edu/',                                             'Horst Severini',        'hs@nhn.ou.edu')
-	reg['am-OU']     = Register(    'am-OU',  'http://www-hep.nhn.ou.edu/pacman-cache/',                                                  'University of Oklahoma',  'http://www-hep.nhn.ou.edu/',                                             'Horst Severini',        'hs@nhn.ou.edu')
-	reg['ATLAS']     = Register(    'ATLAS',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/pacman/slc3/cache/',                 'The Atlas Experiment, CERN',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/sit/Distribution/', 'SIT', 'atlas-sw-sit@cern.ch')
-	reg['Atlas']     = Register(    'Atlas',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/pacman/whole/ATLAS.caches',                 'The Atlas Experiment, CERN',  'http://atlas.web.cern.ch/Atlas/GROUPS/SOFTWARE/OO/sit/Distribution/', 'SIT', 'atlas-sw-sit@cern.ch')
 	reg['CMT']       = Register(      'CMT',  'http://www.cmtsite.org/pacman/cache/',                                                                        'CMT',  'http://www.cmtsite.org/', 'Christian Arnault', 'arnault@lal.in2p3.fr')
+	reg['ITB']       = Register(      'ITB',  'http://software.grid.iu.edu/itb',     'OSG Integration Testbed',  'http://www.opensciencegrid.org', 'Rob Quick', 'rquick@iupui.edu')
 	reg['Pacman']    = Register(   'Pacman',  'http://physics.bu.edu/pacman/sample_cache/',                               'Pacman Headquarters, Boston University',  'http://physics.bu.edu/~youssef/pacman/',  'Saul Youssef',                        'youssef@bu.edu')
 	reg['Demo']      = Register(     'Demo',  'http://physics.bu.edu/pacman/demo/',                                                                 'Pacman Demos',  'http://physics.bu.edu/pacman/',           'Saul Youssef',                        'youssef@bu.edu')
 	reg['BNL']       = Register(      'BNL',  'http://www.usatlas.bnl.gov/computing/cache/',   'Brookhaven National Laboratory',  'http://www.usatlas.bnl.gov/',  'Alex Undrus',       'undrus@bnl.gov')
 	reg['VDT']       = Register(      'VDT',  'http://vdt.cs.wisc.edu/vdt_cache/',                             'Virtual Data Toolkit, University of Wisconson',  'http://vdt.cs.wisc.edu/',  'Alain Roy',                          'roy@cs.wisc.edu')
 	reg['OSG']       = Register(      'OSG',  'http://software.grid.iu.edu/pacman/',                                  'Open Science Grid',  'http://www.opensciencegrid.org/',                 'Leigh Grundhoefer',  'leighg@chestnut.ucs.indiana.edu')
-	reg['UTA']       = Register(      'UTA',  'http://heppc12.uta.edu/pacman/',                                          'Atlas, University of Texas at Arlington',  'http://heppc12.uta.edu/atlas/',           'Kaushik De',                         'kaushik@uta.edu')
-	reg['am-UTA']    = Register(   'am-UTA',  'http://heppc12.uta.edu/pacman/Atlas.mirror',                                          'Atlas, University of Texas at Arlington',  'http://heppc12.uta.edu/atlas/',           'Kaushik De',                         'kaushik@uta.edu')
+	reg['ITB']       = Register(      'ITB',  'http://software.grid.iu.edu/itb/','Open Science Grid Integration Testbed',  'http://www.opensciencegrid.org/',                 'Leigh Grundhoefer',  'leighg@chestnut.ucs.indiana.edu')
+	reg['UTA']       = Register(      'UTA',  'http://www-hep.uta.edu/pacman/',                                          'Atlas, University of Texas at Arlington',  'http://heppc12.uta.edu/atlas/',           'Kaushik De',                         'kaushik@uta.edu')
 	reg['UCHEP']     = Register(    'UCHEP',  'http://grid.uchicago.edu/caches/',                                               'HEP at the University of Chicago',  'http://grid.uchicago.edu/atlaschimera',   'Marco Mambelli',              'marco@hep.uchicago.edu')
-	reg['am-UCHEP']  = Register( 'am-UCHEP',  'http://grid.uchicago.edu/caches/Atlas.mirror/',                                               'HEP at the University of Chicago',  'http://grid.uchicago.edu/atlaschimera',   'Marco Mambelli',              'marco@hep.uchicago.edu')
 	reg['GCL']       = Register(      'GCL',  'http://grid.uchicago.edu/caches/gcl/',                              'Grid Component Library, University of Chicago',  'http://grid.uchicago.edu/gcl/',           'Marco Mambelli',              'marco@hep.uchicago.edu')
 	reg['iVDGL']     = Register(    'iVDGL',  'http://hep.uchicago.edu/ivdgl/',                                       'International Virtual Data Grid Laboratory',  'http://www.ivdgl.org/',                   'Rob Gardner',                   'rwg@hep.uchicago.edu')
         reg['GridCat']   = Register(  'GridCat',  'http://www.ivdgl.org/gridcat/GridCat/',                                                     'Grid Cataloging System', 'http://www.ivdgl.org/',                   'Bockjoo Kim',                   'bockjoo@phys.ufl.edu')
