@@ -14,12 +14,13 @@ class Setup(StringAttr):
 	def __init__(self,string): 
 		self.value = string
 	
-	def shellOut(self,csh,sh,py,pl):
+	def shellOut(self,csh,sh,py,pl,ksh):
 		cshtxt = string.replace(string.replace(self.value,'SHELL','csh'),'SOURCE','source')
 		shtxt  = string.replace(string.replace(self.value,'SHELL','sh'),'SOURCE','.')
 		shtxt  = string.replace(shtxt,'source ','. ')
 		csh.write (cshtxt +'\n')
 		sh. write ( shtxt +'\n')
+		ksh.write ( shtxt +'\n')
 		
 	def satisfied(self):
 		return Reason('['+`self`+'] has not been established yet.',not self.acquired)
