@@ -64,6 +64,7 @@ class SnapshotCache(Cache.Cache):
 		def le(p,q): return p._spec.name<=q._spec.name
 		sort(ps,le)
 		for p in ps: p.display(indent+4)
+#		for p in ps: p.display(indent)
 
 	def load(self):
 		r = Reason()
@@ -75,7 +76,8 @@ class SnapshotCache(Cache.Cache):
 			if r.ok():
 				r,root = parseTar(os.path.join(targetdir,self._filename))
 				self._root = root
-				if r.ok(): r = Execution.execute('cd '+targetdir+'; tar xf '+self._filename)
+#				if r.ok(): r = Execution.execute('cd '+targetdir+'; tar xf '+self._filename)
+				if r.ok(): r = Execution.execute('cd '+targetdir+'; '+gnuTarName()+' xf '+self._filename)
 				if r.ok(): r = Execution.execute('cd '+targetdir+'; rm -f  '+self._filename)
 				if r.ok():
 					try:
@@ -129,6 +131,6 @@ class SnapshotCache(Cache.Cache):
 						Package.reduceCaches(p._environ,p._spec.caches)
 						ps.append(p)
 		if len(ps)==0: r = Reason("Can't find ["+spec.str()+"] in ["+self.UCL+"].")
-		if len(ps)>0 and not switch('l') and not switch('lc'):
+		if len(ps)>0 and not switch('l') and not switch('lc') and not switch('update') and not switch('update-check'):
 			verbo.log('cache','Package ['+ps[0]._spec.str()+'] found in ['+`self`+']...')
 		return r,ps
