@@ -2,24 +2,14 @@
 #	Copyright 2004, Saul Youssef
 #
 from Base        import *
-from Environment import *
-import UniversalAccess,Cache,Package,Source,Message,Trust
+from Environment import * 
+import UniversalAccess,Cache,Package,Source,Message,Trust,Registry
 
 class SourceCache(Cache.Cache):
 	def __init__(self,cache):
 		self.UCL     = cache
 		self.type    = 'source'
 		self._access = UniversalAccess.UniversalAccess(self.UCL,'source')
-	def display(self,indent=0):
-		used = []
-		r,ps = self.getAll(Package.Spec(),used)
-		print indent*' '+`self`
-		if r.ok():
-			def le(p,q): return p._spec.name<=q._spec.name
-			sort(ps,le)
-			for p in ps: p.display(indent+4)
-		else:
-			print indent*' '+`r`
 			
 	def filenames(self,spec):
 		packageFilenames = []
@@ -31,7 +21,9 @@ class SourceCache(Cache.Cache):
 				if spec.filenameEqu(filename): packageFilenames.append(os.path.join(spec.subdirectory,filename))
 				if filename=='lock' and not allow('lock-override'):
 					qlock = 1
-					rr,lines = self._access.getLines('lock')
+					ac = UniversalAccess.UniversalAccess(os.path.join(self.UCL,spec.subdirectory))
+					rr,lines = ac.getLines('lock')
+#					rr,lines = self._access.getLines('lock')
 					if rr.ok() and len(lines)>0 and len(lines[0])>1: lock = lines[0][:-1]
 			
 			packageFilenames.reverse()
@@ -40,8 +32,6 @@ class SourceCache(Cache.Cache):
 	def packageSource(self,spec,path,source):
 		tspec = copy.deepcopy(spec)
 		try:
-#			r,environ,name = Source.SourceFile(source,spec.name,self.UCL,os.path.basename(path)).compN()
-#			r,environ,name = Source.SourceFile(source,spec,self.UCL,os.path.basename(path)).compN()
 			r,environ,name = Source.SourceFile(source,tspec,self.UCL,os.path.basename(path)).compN()
 		except AbortException,message:
 			r,environ,name = Reason(message.value),OR(),spec.name
@@ -53,19 +43,28 @@ class SourceCache(Cache.Cache):
 	
 	def contents(self,used):
 		r,ps = self.getAll(Package.Spec(),[])
-		for i in range(len(ps)): ps[i]._spec.caches.insert(0,self.UCL)
+		if r.ok(): ps   = self.prependTop(ps)
+		if r.ok(): r,ps = self.prepend   (ps)
 		return r,ps
 		
 	def getAll(self,spec,used):
-		r,ps = Trust.trust.add(self.UCL),[]
+		r,ps = Reason(),[]
+		if   len(spec.caches)==0: 
+			pass
+		elif len(spec.caches)==1: 
+			if not Registry.registry.equiv(spec.caches[0],self.UCL):
+				r = Reason("Package ["+spec.str()+"] not found in ["+Registry.registry.short(self.UCL)+"].")
+		else:
+			r = Reason("Package ["+spec.str()+"] not found in ["+Registry.registry.short(self.UCL)+"].")
+		if r.ok(): r = Trust.trust.add(self.UCL)
 		if r.ok(): r,used = self.check(spec,used)
 		
 		if r.ok():
 			r,filenames,qlock,lock = self.filenames(spec)
-			
+
 			if qlock:
 				if string.strip(lock)=='': r = Reason("Cache ["+`self`+"] has been locked by it's owner.")
-				else:                      r = Reason('Cache ['+`self`+"] has been locked.  Message: "+lock)
+				else:                      r = Reason('Cache ['+`self`+"] has been locked by it's owner with message ["+lock+"].")
 						
 			if r.ok():
 				for filename in filenames:
@@ -96,8 +95,14 @@ class SourceCache(Cache.Cache):
 						if spec==Package.Spec() or (r.ok() and spec.satisfiedBy(p)): ps.append(p)
 					else:
 						r = Reason("Can't access ["+filename+"] in cache ["+`self`+"].")	
-	
-			if r.ok() and len(ps)==0: r = Reason("Can't find ["+spec.str()+"] in ["+`self`+"].")
-			if len(ps)>0 and not switch('l') and not switch('lc'): 
-				verbo.log('cache','Package ['+ps[0]._spec.str()+'] found in ['+`self`+']...')
+			
+			if r.ok() and len(ps)==0: 
+				if string.strip(spec.str())=='':
+					r = Reason("Can't find any .pacman source files in ["+`self`+"].")
+				else:
+					r = Reason("Can't find ["+spec.str()+"] in ["+`self`+"].")
+			if len(ps)>0 and not switch('l') and not switch('lc') and not switch('update') and not switch('update-check') and not spec==Package.Spec(): 
+				verbo.log('cache','Package ['+ps[0]._spec.str()+'] found in ['+Registry.registry.short(self.UCL)+']...')
+		if r.ok(): ps   = self.prependTop(ps)
+		if r.ok(): r,ps = self.prepend   (ps)
 		return r,ps
