@@ -1,9 +1,9 @@
 #
 #	Copyright Saul Youssef, July 2003
 #
-from Environment import *
-from FileGetter  import *
-from commandLine import *
+from Environment  import *
+from FileGetter   import *
+from commandCheck import *
 
 class URLvisible(Environment):
 	type   = 'urlVisible'
@@ -35,9 +35,6 @@ class LaunchBrowser(URLvisible):
 	def satisfied(self):
 		return Reason("Web browser hasn't been launched yet.",not self.acquired)
 	def acquire(self):
-		if sys.platform[:6]=='cygwin':
-			return Reason("Can't launch web browser in cygwin.")
-		else:
-			launchwebdisplay(self._url)
-			return Reason()
+		launchwebdisplay(self._url)
+		return Reason()
 	def retract(self): return Reason()
