@@ -209,7 +209,7 @@ class Untarzip(Environment):
 						if os.path.exists(x):
 							if os.path.isdir(x):
 								if allow('tar-overwrite'): pass
-								else:	                   r = ask.re('Untarring ['+self._tarball+'] would overwrite directory ['+x+'] with a file of the same name. Is this OK?')
+								else:	                   r = ask.re('tar-overwrite','Untarring ['+self._tarball+'] would overwrite directory ['+x+'] with a file of the same name. Is this OK?')
 								if r.ok():
 									print 'WARNING: Untarring ['+self._tarball+'] will overwrite directory ['+x+'] with a file.'
 #									r = Reason('Untarring ['+self._tarball+'] would overwrite directory ['+x+'] with a file.')
