@@ -103,6 +103,7 @@ Optional switches with saved defaults (do "-<switch> help" to see the options):\
 Miscellaneous:\n\
   -help,-h                   This message.\n\
   -info                      View documentation in a browser.\n\
+  -bell                      Beep when finished.\n\
   -version                   Show version and platform information.\n\
   -registry                  List registry symbolic names.\n\
   -def                       Display current command line defaults.\n\
@@ -125,8 +126,8 @@ Miscellaneous:\n\
 	print message
 
 legalswitches = ['tar-overwrites','help','h','info','version','v','V','quiet','ask','wget','remove-all','removeall','mirror','snapshot','oldsnap',
-   'fetch','install','uninstall','remove','snap','verify','pretendPlatform','license','def','history','last',
-   'repair','trust-all-caches','ignore-cookies','clear-registry','allow','cache','browser','extract-sources',
+   'fetch','install','uninstall','remove','snap','verify','pretendPlatform','license','def','history','last','bell',
+   'repair','trust-all-caches','ignore-cookies','clear-registry','allow','cache','browser','extract-sources','downloadtimeout',
    'extract-downloads','single','no-compatibility','clear-snapshots','domain','dom','retry','clear-lock','tarpause',
    'clear-preferences','no-download-access-check','debug','l','setup','registry','lc','d','get','o','out','resume',
    'platforms','update-remove','update-check','update','pretend-platform','http-proxy','setups','platform']
@@ -266,7 +267,7 @@ def commandCheck():
 			print 'No http proxy is being used...'
 	if switch('version') or switch('V'):
 		print 'Pacman version:  '+version+version_extra
-		print 'Python version: ',sys.version
+		print 'Python version: ',sys.version.split('\n')[0]
 		Platform().display2()
 		if switch('version'): sys.exit(0)
 	if os.path.exists('README') and os.path.isdir('boot'):
