@@ -22,9 +22,13 @@ def lock():
 			print 'Error reading Pacman directory area.'
 			sys.exit(1)
 	elif os.path.isdir(os.path.join(pac_anchor,pacmanDir)):
-		f = open(path,'w')
-		f.write(getusername()+'\n')
-		f.close()
+		try:
+			f = open(path,'w')
+			f.write(getusername()+'\n')
+			f.close()
+		except (IOError,OSError):
+			print 'Cannot write to ['+os.path.join(pac_anchor,pacmanDir)+'].'
+			sys.exit(1)
 
 def unlock():
 	path = os.path.join(pac_anchor,pacmanDir,'lock')
