@@ -39,5 +39,9 @@ def src():
 	for d in dirs:
 		os.system('cp $PACMAN_LOCATION/st/'+d+'/*.py $PACMAN_LOCATION/src')
 	compileall.compile_dir(os.path.join(os.environ['PACMAN_LOCATION'],'src'))
-	
+	os.system('rm setup.csh')
+	os.system('rm setup.sh')
+	os.system('ln -s scripts/initialize_setup.csh setup.csh')
+	os.system('ln -s scripts/initialize_setup.sh  setup.sh')
+	os.system('cp htmls/Grid.html htmls/grid.html')
 
