@@ -1,6 +1,17 @@
 import sys, socket
 from Base import *
 
+def tryServerSocket(port):
+	sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+	msg = ''
+	try:
+		sock.bind((socket.gethostname(),port))
+		sock.listen(5)
+	except socket.error, msg:
+		if msg=='': msg = "Can't bind to port ["+`port`+"]."
+	sock.close()
+	return msg		
+
 def checkTCPPort(host, port):
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     try:
