@@ -23,8 +23,10 @@ def urlFiles(path,dirs=0):
 		sock = urllib2.urlopen(path)
 		text = sock.read()
 		sock.close()
-	except AssertionError:
-		abort("Internal Python error attempting to access ["+path+"].")
+#	except AssertionError:
+#		abort("Internal Python error attempting to access ["+path+"].")
+	except KeyboardInterrupt:
+		reason = Reason("Download interrupted by ^C.")
 	except:
 		reason = Reason("Can't access ["+path+"].")
 	
